--[[ Changelog:
	1.0 : Initial release
	1.1 : Added "(currently xxx)" to end of "Requires (Fishing, Cooking, etc.)" messages. For example, "Requires Mining 500 (currently 496)"
	1.2 : Added command to print highest herb/mob/mine you can pick/skin/mine, fixed "Requires skinning knife (currently 0)" bug
]]

function GN_OnLoad(self)
	self:RegisterEvent("CHAT_MSG_SKILL")
	self:RegisterEvent("UI_ERROR_MESSAGE")
	UIErrorsFrame:UnregisterEvent("UI_ERROR_MESSAGE")
	
	GN_Version = GetAddOnMetadata("GatherNotify","Version")
end

function GN_Test(skill,level)
	GN_OnEvent(nil,"UI_ERROR_MESSAGE",string.format("Requires %s %s",skill,level))
end

function GN_OnEvent(self, event, ...)
	if (event == "CHAT_MSG_SKILL") then
		local _,_,skill = string.find(...,"Your skill in (%a*) has increased to")
		local _,_,level = string.find(...,"Your skill in .* has increased to (%d*)")
		level = tonumber(level)
		
		if (skill == "Skinning" and GN_LevelToGatherable("skinning",level)) then
			GN_Msg("Skinning increased to "..level..". Now able to skin level " .. GN_LevelToGatherable("skinning",level))
		elseif (skill == "Mining" and GN_LevelToGatherable("mining",level)) then
			GN_Msg("Mining increased to "..level..". Now able to mine: " .. GN_LevelToGatherable("mining",level))
		elseif (skill == "Herbalism" and GN_LevelToGatherable("herbalism",level)) then
			GN_Msg("Herbalism increased to "..level..". Now able to pick: " .. GN_LevelToGatherable("herbalism",level))
		end
		
	elseif (event == "UI_ERROR_MESSAGE") then
		local _,_,skill = string.find(...,"Requires (.*) ")
		local _,_,rlevel = string.find(...,"Requires .* (%d+)")
		
		if ((skill ~= nil) and (rlevel ~= nil)) then -- Error was a "requires" error
			p1,p2,p3,p4,p5,p6 = GetProfessions()
			if (p1) then prof1 = GetProfessionInfo(p1) end -- Profession 1
			if (p2) then prof2 = GetProfessionInfo(p2) end -- Profession 2
			if (p3) then prof3 = GetProfessionInfo(p3) end -- Archaeology
			if (p4) then prof4 = GetProfessionInfo(p4) end -- Fishing
			if (p5) then prof5 = GetProfessionInfo(p5) end -- Cooking
			if (p6) then prof6 = GetProfessionInfo(p6) end -- First Aid
			
			if (prof1 == skill) then     -- Profession 1 matches required profession
				_,_,current = GetProfessionInfo(p1)
				GN_AddError(skill,rlevel,current)
			elseif (prof2 == skill) then -- Profession 2 matches required profession
				_,_,current = GetProfessionInfo(p2)
				GN_AddError(skill,rlevel,current)
			elseif (prof3 == skill) then -- Required profession is archaeology
				_,_,current = GetProfessionInfo(p3)
				GN_AddError(skill,rlevel,current)
			elseif (prof4 == skill) then -- Required profession is fishing
				_,_,current = GetProfessionInfo(p4)
				GN_AddError(skill,rlevel,current)
			elseif (prof5 == skill) then -- Required profession is cooking
				_,_,current = GetProfessionInfo(p5)
				GN_AddError(skill,rlevel,current)
			elseif (prof6 == skill) then -- Required profession is first aid
				_,_,current = GetProfessionInfo(p6)
				GN_AddError(skill,rlevel,current)
			else
				-- Doesn't match a profession we have, so just print the standard error
				UIErrorsFrame:AddMessage(...,1,.1,.1)
			end
		else
			UIErrorsFrame:AddMessage(...,1,.1,.1)
		end
	end
end

function GN_AddError(s,r,c)
	UIErrorsFrame:AddMessage(string.format("Requires %s %s (currently %s)",s,r,c),1.0,0.1,0.1,1.0)
end

function GN_Msg(msg)
	DEFAULT_CHAT_FRAME:AddMessage("|cffd2b48c[GatherNotify]|r "..msg)
end

SLASH_GN1, SLASH_GN2, SLASH_GN3 = '/gn', '/gathernotify', '/gnotify'
function SlashCmdList.GN(cmd)
	cmd = string.lower(cmd)
	if (cmd == "s" or cmd == "skinning") then
		GN_PrintHighest("skinning")
	elseif (cmd == "m" or cmd == "mining") then
		GN_PrintHighest("mining")
	elseif (cmd == "h" or cmd == "herbalism") then
		GN_PrintHighest("herbalism")
	elseif (cmd == "v" or cmd == "ver" or cmd == "version") then
		GN_Msg("GatherNotify version: "..GN_Version)
	else
		GN_Msg("/gn skinning - Print highest level creature you can skin")
		GN_Msg("/gn mining - Print highest node you can mine")
		GN_Msg("/gn herbalism - Print highest herb you can pick")
		GN_Msg("/gn version - Prints addon version")
	end
end

function GN_PrintHighest(skill)
	skill = string.lower(skill)
	p1,p2 = GetProfessions()
	if (p1) then prof1 = GetProfessionInfo(p1) end -- Profession 1
	if (p2) then prof2 = GetProfessionInfo(p2) end -- Profession 2
	
	if (skill == "skinning") then
	
		if (prof1 == "Skinning") then
			_,_,level = GetProfessionInfo(p1)
			GN_Msg("Able to skin level "..GN_FindHighest("skinning",level))
		elseif (prof2 == "Skinning") then
			_,_,level = GetProfessionInfo(p2)
			GN_Msg("Able to skin level "..GN_FindHighest("skinning",level))
		else
			GN_Msg("You don't have Skinning")
		end
	
	elseif (skill == "mining") then
	
		if (prof1 == "Mining") then
			_,_,level = GetProfessionInfo(p1)
			GN_Msg("Able to mine "..GN_FindHighest("mining",level))
		elseif (prof2 == "Mining") then
			_,_,level = GetProfessionInfo(p2)
			GN_Msg("Able to mine "..GN_FindHighest("mining",level))
		else
			GN_Msg("You don't have Mining")
		end
	
	elseif (skill == "herbalism") then
	
		if (prof1 == "Herbalism") then
			_,_,level = GetProfessionInfo(p1)
			GN_Msg("Able to skin level "..GN_FindHighest("herbalism",level))
		elseif (prof2 == "Herbalism") then
			_,_,level = GetProfessionInfo(p2)
			GN_Msg("Able to skin level "..GN_FindHighest("herbalism",level))
		else
			GN_Msg("You don't have Herbalism")
		end
	
	end
end

function GN_LevelToGatherable(skill, level,verbose)
	skill = string.lower(skill)
	
	if (skill == "skinning") then
		
		if ((level < 100) and (level % 10 == 0)) then -- If level is under 100, and is a multiple of 10
			local clevel = (level/10)+10
			return clevel.." creatures"
		elseif ((level >= 100) and (level <= 365) and (level % 5 == 0)) then -- If level is between 100 and 365, and is a multiple of 5
			local clevel = level/5
			return clevel.." creatures"
			
		elseif (level == 375) then return "74 creatures"
		elseif (level == 385) then return "75 creatures"
		elseif (level == 395) then return "76 creatures"
		elseif (level == 405) then return "77 creatures"
		elseif (level == 415) then return "78 creatures"
		elseif (level == 425) then return "79 creatures"
		elseif (level == 435) then return "80 creatures"
		elseif (level == 440) then return "81 creatures"
		elseif (level == 445) then return "82 creatures"
		elseif (level == 450) then return "83 creatures"
		elseif (level == 470) then return "84 creatures"
		elseif (level == 490) then return "85 creatures"
		end
		
	elseif (skill == "mining") then
		
			 if (level == 50) then return "Tin"
		 elseif (level == 65) then return "Silver"
		elseif (level == 100) then return "Iron"
		elseif (level == 115) then return "Gold"
		elseif (level == 150) then return "Mithril"
		elseif (level == 165) then return "Truesilver and Dark Iron"
		elseif (level == 200) then return "Small Thorium"
		elseif (level == 215) then return "Rich Thorium"
		elseif (level == 275) then return "Fel Iron"
		elseif (level == 325) then return "Adamantite"
		elseif (level == 350) then return "Rich Adamantite and Cobalt"
		elseif (level == 375) then return "Khorium and Rich Cobalt"
		elseif (level == 400) then return "Saronite"
		elseif (level == 425) then return "Rich Saronite and Obsidium"
		elseif (level == 450) then return "Rich Obsidium and Titanium"
		elseif (level == 475) then return "Elementium"
		elseif (level == 500) then return "Rich Elementium"
		elseif (level == 525) then return "Pyrite and Rich Pyrite"
		end
		
	elseif (skill == "herbalism") then
		
			 if (level == 15) then return "Earthroot"
		 elseif (level == 50) then return "Mageroyal"
		 elseif (level == 70) then return "Briarthorn"
		 elseif (level == 85) then return "Stranglekelp and Bruiseweed"
		elseif (level == 105) then return "Grave Moss"
		elseif (level == 115) then return "Wild Steelbloom"
		elseif (level == 125) then return "Kingsblood"
		elseif (level == 150) then return "Liferoot, Fadeleaf and Goldthorn"
		elseif (level == 160) then return "Khadgar's Whisker"
		elseif (level == 195) then return "Dragon's Teeth"
		elseif (level == 205) then return "Firebloom"
		elseif (level == 210) then return "Purple Lotus"
		elseif (level == 220) then return "Arthas' Tears"
		elseif (level == 230) then return "Sungrass"
		elseif (level == 235) then return "Blindweed"
		elseif (level == 245) then return "Ghost Mushroom"
		elseif (level == 250) then return "Gromsblood"
		elseif (level == 260) then return "Golden Sansam"
		elseif (level == 270) then return "Dreamfoil"
		elseif (level == 280) then return "Mountain Silversage"
		elseif (level == 285) then return "Sorrowmoss"
		elseif (level == 290) then return "Icecap"
		elseif (level == 300) then return "Black Lotus and Felweed"
		elseif (level == 315) then return "Dreaming Glory"
		elseif (level == 325) then return "Ragveil and Terocone"
		elseif (level == 335) then return "Flame Cap"
		elseif (level == 340) then return "Ancient Lichen"
		elseif (level == 350) then return "Netherbloom and Goldclover"
		elseif (level == 360) then return "Firethorn"
		elseif (level == 365) then return "Nightmare Vine"
		elseif (level == 375) then return "Mana Thistle and Tiger Lily"
		elseif (level == 385) then return "Talandra's Rose"
		elseif (level == 400) then return "Frozen Herb and Adder's Tongue"
		elseif (level == 425) then return "Lichbloom, Cinderbloom, Stormvine and Azshara's Veil"
		elseif (level == 435) then return "Icethorn"
		elseif (level == 450) then return "Frost Lotus"
		elseif (level == 475) then return "Heartblossom"
		elseif (level == 500) then return "Whiptail"
		elseif (level == 525) then return "Twilight Jasmine"
		end
	end
end

function GN_FindHighest(skill,level)
	skill = string.lower(skill)
	
	if (skill == "skinning") then
	
			if (level >= 490) then return "85 creatures"
		elseif (level >= 470) then return "84 creatures"
		elseif (level >= 450) then return "83 creatures"
		elseif (level >= 445) then return "82 creatures"
		elseif (level >= 440) then return "81 creatures"
		elseif (level >= 435) then return "80 creatures"
		elseif (level >= 425) then return "79 creatures"
		elseif (level >= 415) then return "78 creatures"
		elseif (level >= 405) then return "77 creatures"
		elseif (level >= 395) then return "76 creatures"
		elseif (level >= 385) then return "75 creatures"
		elseif (level >= 375) then return "74 creatures"
		
		elseif ((level >= 100) and (level <= 365)) then -- If level is between 100 and 365
			local clevel = math.floor(level/5)
			return clevel.." creatures"
		
		else -- If level is under 100
			local clevel = math.floor((level/10)+10)
			return clevel.." creatures"
		end
		
	elseif (skill == "mining") then
	
		if (level >= 525) then return "Pyrite and Rich Pyrite"
		elseif (level >= 500) then return "Rich Elementium"
		elseif (level >= 475) then return "Elementium"
		elseif (level >= 450) then return "Rich Obsidium and Titanium"
		elseif (level >= 425) then return "Rich Saronite and Obsidium"
		elseif (level >= 400) then return "Saronite"
		elseif (level >= 375) then return "Khorium and Rich Cobalt"
		elseif (level >= 350) then return "Rich Adamantite and Cobalt"
		elseif (level >= 325) then return "Adamantite"
		elseif (level >= 275) then return "Fel Iron"
		elseif (level >= 215) then return "Rich Thorium"
		elseif (level >= 200) then return "Small Thorium"
		elseif (level >= 165) then return "Truesilver and Dark Iron"
		elseif (level >= 150) then return "Mithril"
		elseif (level >= 115) then return "Gold"
		elseif (level >= 100) then return "Iron"
		elseif (level >= 65) then return "Silver"
		elseif (level >= 50) then return "Tin"
		else return "Copper"
		end
		
	elseif (skill == "herbalism") then
		
			if (level >= 525) then return "Twilight Jasmine"
		elseif (level >= 500) then return "Whiptail"
		elseif (level >= 475) then return "Heartblossom"
		elseif (level >= 450) then return "Frost Lotus"
		elseif (level >= 435) then return "Icethorn"
		elseif (level >= 425) then return "Lichbloom, Cinderbloom, Stormvine and Azshara's Veil"
		elseif (level >= 400) then return "Frozen Herb and Adder's Tongue"
		elseif (level >= 385) then return "Talandra's Rose"
		elseif (level >= 375) then return "Mana Thistle and Tiger Lily"
		elseif (level >= 365) then return "Nightmare Vine"
		elseif (level >= 360) then return "Firethorn"
		elseif (level >= 350) then return "Netherbloom and Goldclover"
		elseif (level >= 340) then return "Ancient Lichen"
		elseif (level >= 335) then return "Flame Cap"
		elseif (level >= 325) then return "Ragveil and Terocone"
		elseif (level >= 315) then return "Dreaming Glory"
		elseif (level >= 300) then return "Black Lotus and Felweed"
		elseif (level >= 290) then return "Icecap"
		elseif (level >= 285) then return "Sorrowmoss"
		elseif (level >= 280) then return "Mountain Silversage"
		elseif (level >= 270) then return "Dreamfoil"
		elseif (level >= 260) then return "Golden Sansam"
		elseif (level >= 250) then return "Gromsblood"
		elseif (level >= 245) then return "Ghost Mushroom"
		elseif (level >= 235) then return "Blindweed"
		elseif (level >= 230) then return "Sungrass"
		elseif (level >= 220) then return "Arthas' Tears"
		elseif (level >= 210) then return "Purple Lotus"
		elseif (level >= 205) then return "Firebloom"
		elseif (level >= 195) then return "Dragon's Teeth"
		elseif (level >= 160) then return "Khadgar's Whisker"
		elseif (level >= 150) then return "Liferoot, Fadeleaf and Goldthorn"
		elseif (level >= 125) then return "Kingsblood"
		elseif (level >= 115) then return "Wild Steelbloom"
		elseif (level >= 105) then return "Grave Moss"
		 elseif (level >= 85) then return "Stranglekelp and Bruiseweed"
		 elseif (level >= 70) then return "Briarthorn"
		 elseif (level >= 50) then return "Mageroyal"
		 elseif (level >= 15) then return "Earthroot"
		else return "Peacebloom and Silverleaf"
		end
	end
end